# CONTRIBUTIONS and CODE REVIEWS

We love contributions from the community. Please send pull requests and raise
issues! All code submissions require review. We use GitHub pull requests for
this purpose.

> [!IMPORTANT]
> Contributions that were generated in whole or in-part from any
> language model or AI, such as GitHub Copilot, ChatGPT, BARD, or any other such tool
> are explicitly forbidden and will result in your permanent ban from contributing
> to this project.

# COPYRIGHTS and LICENSE

Torii is licensed under the [BSD-2-Clause], the full text of which can be found in the [`LICENSE`] file in the root of this repository.

All authors retain copyright ownership of their contributions.

Authors should note that all contributions are licensed under the [BSD-2-Clause].


# CONTRIBUTORS

The complete list of contributors is contained within the git repository.
Tools such as the git log command can be used to see all contributions and
contributors.


[BSD-2-Clause]: https://spdx.org/licenses/BSD-2-Clause.html
[`LICENSE`]: ./LICENSE
